#
# spec file for package python-seaborn
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Spurious test failures due to upstream changes
# Should be fixed in next release after 0.7.1
%bcond_with tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-seaborn
Version:        0.8.1
Release:        lp152.3.5
Summary:        Statistical data visualization for python
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://pypi.python.org/pypi/seaborn/
Source:         https://files.pythonhosted.org/packages/source/s/seaborn/seaborn-%{version}.tar.gz
BuildRequires:  %{python_module Pillow}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module fastcluster}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module patsy}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module statsmodels}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with tests}
# Testing requirements
BuildRequires:  %{python_module jupyter_ipython}
BuildRequires:  %{python_module jupyter_notebook}
BuildRequires:  %{python_module nose}
BuildConflicts: python-buildservice-tweak
%endif
Requires:       python-matplotlib
Requires:       python-numpy
Requires:       python-pandas
Requires:       python-scipy
Requires:       python-six
Recommends:     python-Pillow
Recommends:     python-fastcluster
Recommends:     python-patsy
Recommends:     python-statsmodels
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%python_subpackages

%description
Seaborn is a library for making attractive and informative
statistical graphics in Python. It is built on top of
matplotlib and tightly integrated with the PyData stack,
including support for numpy and pandas data structures and
statistical routines from scipy and statsmodels.

Some of the features that seaborn offers are:
- Several built-in themes that improve on the default matplotlib
  aesthetics
- Tools for choosing color palettes to make beautiful plots that
  reveal patterns in your data
- Functions for visualizing univariate and bivariate distributions
  or for comparing them between subsets of data
- Tools that fit and visualize linear regression models for different
  kinds of independent and dependent variables
- Functions that visualize matrices of data and use clustering
  algorithms to discover structure in those matrices
- A function to plot statistical timeseries data with flexible
  estimation and representation of uncertainty around the estimate
- High-level abstractions for structuring grids of plots that let you
  easily build complex visualizations

%prep
%setup -q -n seaborn-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with tests}
%check
%{python_expand export PYTHONPATH="%{buildroot}%{$python_sitelib}"
nosetests-%{$python_bin_suffix}
}
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc LICENSE README.md
%doc licences/
%{python_sitelib}/*

%changelog
* Thu Nov  2 2017 arun@gmx.de
- update to version 0.8.1:
  * Added a warning in :class:`FacetGrid` when passing a categorical
    plot function without specifying "order" (or "hue_order" when
    "hue" is used), which is likely to produce a plot that is
    incorrect.
  * Improved compatibility between :class:`FacetGrid` or
    :class:`PairGrid` and interactive matplotlib backends so that the
    legend no longer remains inside the figure when using
    "legend_out=True".
  * Changed categorical plot functions with small plot elements to use
    :func:`dark_palette` instead of :func:`light_palette` when
    generating a sequential palette from a specified color.
  * Improved robustness of :func:`kdeplot` and :func:`distplot` to
    data with fewer than two observations.
  * Fixed a bug in :func:`clustermap` when using "yticklabels=False".
  * Fixed a bug in :func:`pointplot` where colors were wrong if
    exactly three points were being drawn.
  * Fixed a bug in :func:`pointplot` where legend entries for missing
    data appeared with empty markers.
  * Fixed a bug in :func:`clustermap` where an error was raised when
    annotating the main heatmap and showing category colors.
  * Fixed a bug in :func:`clustermap` where row labels were not being
    properly rotated when they overlapped.
  * Fixed a bug in :func:`kdeplot` where the maximum limit on the
    density axes was not being updated when multiple densities were
    drawn.
  * Improved compatibility with future versions of pandas.
* Thu Aug 17 2017 toddrme2178@gmail.com
- Update to version 0.8.0
  * The default style is no longer applied when seaborn is
    imported. It is now necessary to explicitly call set() or one
    or more of set_style(), set_context(), and set_palette().
    Correspondingly, the seaborn.apionly module has been
    deprecated.
  * Changed the behavior of heatmap() (and by extension
    clustermap()) when plotting divergent dataesets (i.e. when
    the center parameter is used). Instead of extending the lower
    and upper limits of the colormap to be symettrical around the
    center value, the colormap is modified so that its middle color
    corresponds to center. This means that the full range of the
    colormap will not be used (unless the data or specified vmin
    and vmax are symettric), but the upper and lower limits of
    the colorbar will correspond to the range of the data. See the
    Github pull request (#1184) for examples of the behavior.
  * Removed automatic detection of diverging data in heatmap()
    (and by extension clustermap()). If you want the colormap to
    be treated as diverging (see above), it is now necessary to
    specify the center value. When no colormap is specified,
    specifying center will still change the default to be one that
    is more appropriate for displaying diverging data.
  * Added four new colormaps, created using viscm for perceptual
    uniformity. The new colormaps include two sequential colormaps
    (“rocket” and “mako”) and two diverging colormaps (“icefire”
    and “vlag”). These colormaps are registered with matplotlib on
    seaborn input and the colormap objects can be accessed in the
    seaborn.cm namespace.
  * Changed the default heatmap() colormaps to be “rocket” (in the
    case of sequential data) or “icefire” (in the case of diverging
    data). Note that this change reverses the direction of the
    luminance ramp from the previous defaults. While potentially
    confusing and disruptive, this change better aligns the seaborn
    defaults with the new matplotlib default colormap (“viridis”)
    and arguably better aligns the semantics of a “heat” map with
    the appearance of the colormap.
  * Added "auto" as a (default) option for tick labels in heatmap()
    and clustermap(). This will try to estimate how many ticks can
    be labeled without the text objects overlapping, which should
    improve performance for larger matrices.
  * Added the dodge parameter to boxplot(), violinplot(), and
    barplot() to allow use of hue without changing the position or
    width of the plot elements, as when the hue varible is not
    nested within the main categorical variable.
  * Correspondingly, the split parameter for stripplot() and
    swarmplot() has been renamed to dodge for consistency with the
    other categorical functions (and for differentiation from the
    meaning of split in violinplot()).
  * Added the ability to draw a colorbar for a bivariate kdeplot()
    with the cbar parameter (and related cbar_ax and cbar_kws
    parameters).
  * Added the ability to use error bars to show standard deviations
    rather than bootstrap confidence intervals in most statistical
    functions by putting ci="sd".
  * Allow side-specific offsets in despine().
  * Figure size is no longer part of the seaborn plotting context
    parameters.
  * Put a cap on the number of bins used in jointplot() for
    type=="hex" to avoid hanging when the reference rule prescribes
    too many.
  * Turn off dendrogram axes in clustermap() rather than setting
    the background color to white.
  * New matplotlib qualitative palettes (e.g. “tab10”) are now
    handled correctly.
  * Some modules and functions have been internally reorganized;
    there should be no effect on code that uses the seaborn
    namespace.
  * Added a deprecation warning to tsplot() function to indicate
    that it will be removed or replaced with a substantially
    altered version in a future release.
  * The interactplot and coefplot functions are officially
    deprecated and will be removed in a future release.
* Thu May  4 2017 toddrme2178@gmail.com
- Implement singlespec version.
* Wed Mar  1 2017 toddrme2178@gmail.com
- Temporarily disable tests.  There are multiple spurious test
  failures due to upstream changes that do not affect real-world
  usage.  Tests should be re-enabled in next release.
* Mon Sep 19 2016 toddrme2178@gmail.com
- update to version 0.7.1:
  * Added the ability to put "caps" on the error bars that are drawn
    by :func:`barplot` or :func:`pointplot` (and, by extension,
    :func:`factorplot`). Additionally, the line width of the error
    bars can now be controlled. These changes involve the new
    parameters "capsize" and "errwidth". See the `github pull request
    <https://github.com/mwaskom/seaborn/pull/898>`_ for examples of
    usage.
  * Improved the row and column colors display in
    :func:`clustermap`. It is now possible to pass Pandas objects for
    these elements and, when possible, the semantic information in the
    Pandas objects will be used to add labels to the plot. When Pandas
    objects are used, the color data is matched against the main
    heatmap based on the index, not on position. This is more
    accurate, but it may lead to different results if current code
    assumed positional matching.
  * Improved the luminance calculation that determines the annotation
    color in :func:`heatmap`.
  * The "annot" parameter of :func:`heatmap` now accepts a rectangular
    dataset in addition to a boolean value. If a dataset is passed,
    its values will be used for the annotations, while the main
    dataset will be used for the heatmap cell colors.
  * Fixed a bug in :class:`FacetGrid` that appeared when using
    "col_wrap" with missing "col" levels.
  * Made it possible to pass a tick locator object to the
    :func:`heatmap` colorbar.
  * Made it possible to use different styles (e.g., step) for
    :class:`PairGrid` histograms when there are multiple hue levels.
  * Fixed a bug in scipy-based univariate kernel density bandwidth
    calculation.
  * The :func:`reset_orig` function (and, by extension, importing
    "seaborn.apionly") resets matplotlib rcParams to their values at
    the time seaborn itself was imported, which should work better
    with rcParams changed by the jupyter notebook backend.
  * Removed some objects from the top-level "seaborn" namespace.
  * Improved unicode compatibility in :class:`FacetGrid`.
- Update to 0.7.0
  - Added the :func:`swarmplot` function, which draws beeswarm
    plots. These are categorical scatterplots, similar to those
    produced by :func:`stripplot`, but position of the points on
    the categorical axis is chosen to avoid overlapping points.
  - Changed some of the :func:`stripplot` defaults to be closer
    to :func:`swarmplot`. Points are now somewhat smaller, have
    no outlines, and are not split by default when using ``hue``.
    These settings remain customizable through function
    parameters.
  - Added an additional rule when determining category order in
    categorical plots. Now, when numeric variables are used in a
    categorical role, the default behavior is to sort the unique
    levels of the variable (i.e they will be in proper numerical
    order). This can still be overridden by the appropriate
    ``{*_}order`` parameter, and variables with a ``category``
    datatype will still follow the category order even if the
    levels are strictly numerical.
  - Changed how :func:`stripplot` draws points when using
  ``hue`` nesting with ``split=False`` so that the different
  ``hue`` levels are not drawn strictly on top of each other.
  - Improve performance for large dendrograms in
    :func:`clustermap`.
  - Added ``font.size`` to the plotting context definition so
    that the default output from ``plt.text`` will be scaled
    appropriately.
  - Fixed a bug in :func:`clustermap` when ``fastcluster`` is
    not installed.
  - Fixed a bug in the zscore calculation in
    :func:`clustermap`.
  - Fixed a bug in :func:`distplot` where sometimes the default
    number of bins would not be an integer.
  - Fixed a bug in :func:`stripplot` where a legend item would
    not appear for a ``hue`` level if there were no observations
    in the first group of points.
  - Heatmap colorbars are now rasterized for better performance
    in vector plots.
  - Added workarounds for some matplotlib boxplot issues, such as
    strange colors of outlier points.
  - Added workarounds for an issue where violinplot edges would be
    missing or have random colors.
  - Added a workaround for an issue where only one :func:`heatmap`
    cell would be annotated on some matplotlib backends.
  - Fixed a bug on newer versions of matplotlib where a colormap
    would be erroneously applied to scatterplots with only three
    observations.
  - Updated seaborn for compatibility with matplotlib 1.5.
  - Added compatibility for various IPython (and Jupyter) versions
    in functions that use widgets.
- Add python3-seaborn-0.7.0-remove_color_list _from_dendrogram_call_in_tests.patch
  to fix compatibility with python3-scipy 0.17.0
* Wed Jul  1 2015 toddrme2178@gmail.com
- Update to 0.6.0
  * Changed plotting functions
  - In version 0.6, the "categorical" plots have been unified with a common
    API
  - Changes to :func:`boxplot` and :func:`violinplot` will probably be the
    most disruptive. Both functions maintain backwards-compatibility in
    terms of the kind of data they can accept, but the syntax has changed to
    be more similar to other seaborn functions. These functions are now
    invoked with ``x`` and/or  ``y`` parameters that are either vectors of
    data or names of variables in a  long-form DataFrame passed to the new
    ``data`` parameter. You can still pass wide-form DataFrames or arrays to
    ``data``, but it is no longer the first  positional argument. See the
    `github pull request <https://github.com/mwaskom/seaborn/pull/410>`_ for
    more information on these  changes and the logic behind them.
  - As :func:`pointplot` and :func:`barplot` can now plot with the major
    categorical variable on the y axis, the ``x_order`` parameter has been
    renamed to ``order``.
  - Added a ``hue`` argument to :func:`boxplot` and :func:`violinplot`,
    which allows for nested grouping the plot elements by a third
    categorical variable. For :func:`violinplot`, this nesting can also be
    accomplished by splitting the violins when there are two levels of the
    ``hue`` variable (using ``split=True``). To make this functionality
    feasible, the ability to specify where the plots will be draw in data
    coordinates has been removed. These plots now are drawn at set
    positions, like (and identical to) :func:`barplot` and :func:`pointplot`.
  - Added a ``palette`` parameter to :func:`boxplot`/:func:`violinplot`. The
    ``color`` parameter still exists, but no longer does double-duty in
    accepting the name of a seaborn palette. ``palette`` supersedes
    ``color`` so that it can be used with a :class:`FacetGrid`.
  - The default rules for ordering the categories has changed. Instead of
    automatically sorting the category levels, the plots now show the levels
    in the order they appear in the input data (i.e., the order given by
    ``Series.unique()``). Order can be specified when plotting with the
    ``order`` and ``hue_order`` parameters. Additionally, when variables are
    pandas objects with a "categorical" dtype, the category order is
    inferred from the data object. This change also affects
    :class:`FacetGrid` and :class:`PairGrid`.
  - Added the ``scale`` and ``scale_hue`` parameters to :func:`violinplot`.
    These control how the width of the violins are scaled. The default is
    ``area``, which is different from how the violins used to be drawn. Use
    ``scale='width'`` to get the old behavior.
  - Used a different style for the ``box`` kind of interior plot in
    :func:`violinplot`, which shows the whisker range in addition to the
    quartiles. Use ``inner='quartile'`` to get the old style.
  * New plotting functions
  - Added the :func:`stripplot` function, which draws a scatterplot where
    one of the variables is categorical. This plot has the same API as
    :func:`boxplot` and :func:`violinplot`. It is useful both on its own and
    when composed with one of these other plot kinds to show both the
    observations and underlying distribution.
  - Added the :func:`countplot` function, which uses a bar plot
    representation to show counts of variables in one or more categorical
    bins. This replaces the old approach of calling :func:`barplot` without
    a numeric variable.
  * Other additions and changes
  - The :func:`corrplot` and underlying :func:`symmatplot` functions have
    been deprecated in favor of :func:`heatmap`, which is much more flexible
    and robust. These two functions are still available in version 0.6, but
    they will be removed in a future version.
  - Added the :func:`set_color_codes` function and the ``color_codes``
    argument to :func:`set` and :func:`set_palette`. This changes the
    interpretation of shorthand color codes (i.e. "b", "g", k", etc.) within
    matplotlib to use the values from one of the named seaborn palettes
    (i.e. "deep", "muted", etc.). That makes it easier to have a more
    uniform look when using matplotlib functions directly with seaborn
    imported. This could be disruptive to existing plots, so it does not
    happen by default. It is possible this could change in the future.
  - The :func:`color_palette` function no longer trims palettes that are
    longer than 6 colors when passed into it.
  - Added the ``as_hex`` method to color palette objects, to return a list
    of hex codes rather than rgb tuples.
  - :func:`jointplot` now passes additional keyword arguments to the
    function used to draw the plot on the joint axes.
  - Changed the default ``linewidths`` in :func:`heatmap` and
    :func:`clustermap` to 0 so that larger matrices plot correctly. This
    parameter still exists and can be used to get the old effect of lines
    demarcating each cell in the heatmap (the old default ``linewidths`` was
    0.5).
  - :func:`heatmap` and :func:`clustermap` now automatically use a mask for
    missing values, which previously were shown with the "under" value of
    the colormap per default `plt.pcolormesh` behavior.
  - Added the ``seaborn.crayons`` dictionary and the :func:`crayon_palette`
    function to define colors from the 120 box (!) of `Crayola crayons
    <http://en.wikipedia.org/wiki/List_of_Crayola_crayon_colors>`_.
  - Added the ``line_kws`` parameter to :func:`residplot` to change the
    style of the lowess line, when used.
  - Added open-ended ``**kwargs`` to the ``add_legend`` method on
    :class:`FacetGrid` and :class:`PairGrid`, which will pass additional
    keyword arguments through when calling the legend function on the
    ``Figure`` or ``Axes``.
  - Added the ``gridspec_kws`` parameter to :class:`FacetGrid`, which allows
    for control over the size of individual facets in the grid to emphasize
    certain plots or account for differences in variable ranges.
  - The interactive palette widgets now show a continuous colorbar, rather
    than a discrete palette, when `as_cmap` is True.
  - The default Axes size for :func:`pairplot` and :class:`PairGrid` is now
    slightly smaller.
  - Added the ``shade_lowest`` parameter to :func:`kdeplot` which will set
    the alpha for the lowest contour level to 0, making it easier to plot
    multiple bivariate distributions on the same axes.
  - The ``height`` parameter of :func:`rugplot` is now interpreted as a
    function of the axis size and is invariant to changes in the data scale
    on that axis. The rug lines are also slightly narrower by default.
  - Added a catch in :func:`distplot` when calculating a default number of
    bins. For highly skewed data it will now use sqrt(n) bins, where
    previously the reference rule would return "infinite" bins and cause an
    exception in matplotlib.
  - Added a ceiling (50) to the default number of bins used for
    :func:`distplot` histograms. This will help avoid confusing errors with
    certain kinds of datasets that heavily violate the assumptions of the
    reference rule used to get a default number of bins. The ceiling is not
    applied when passing a specific number of bins.
  - The various property dictionaries that can be passed to ``plt.boxplot``
    are now applied after the seaborn restyling to allow for full
    customizability.
  - Added a ``savefig`` method to :class:`JointGrid` that defaults to a
    tight bounding box to make it easier to save figures using this class,
    and set a tight bbox as the default for the ``savefig`` method on other
    Grid objects.
  - You can now pass an integer to the ``xticklabels`` and ``yticklabels``
    parameter of :func:`heatmap` (and, by extension, :func:`clustermap`).
    This will make the plot use the ticklabels inferred from the data, but
    only plot every ``n`` label, where ``n`` is the number you pass. This
    can help when visualizing larger matrices with some sensible ordering to
    the rows or columns of the dataframe.
  - Added `"figure.facecolor"` to the style parameters and set the default
    to white.
  - The :func:`load_dataset` function now caches datasets locally after
    downloading them, and uses the local copy on subsequent calls.
  * Bug fixes
  - Fixed bugs in :func:`clustermap` where the mask and specified ticklabels
    were not being reorganized using the dendrograms.
  - Fixed a bug in :class:`FacetGrid` and :class:`PairGrid` that lead to
    incorrect legend labels when levels of the ``hue`` variable appeared in
    ``hue_order`` but not in the data.
  - Fixed a bug in :meth:`FacetGrid.set_xticklabels` or
    :meth:`FacetGrid.set_yticklabels` when ``col_wrap`` is being used.
  - Fixed a bug in :class:`PairGrid` where the ``hue_order`` parameter was
    ignored.
  - Fixed two bugs in :func:`despine` that caused errors when trying to trim
    the spines on plots that had inverted axes or no ticks.
  - Improved support for the ``margin_titles`` option in :class:`FacetGrid`,
    which can now be used with a legend.
* Fri Nov 28 2014 toddrme2178@gmail.com
- Initial version
